@@ -13,22 +13,24 @@ class Strategy:
     file_path = '{0}_Strategy.json'.format(datetime.today().strftime("%Y%m%d"))
     saved_data = {}
     
-    def __init__( self, period = 700, target = .3, stop_loss = .15, tsl_period = 10, useSD = False):
+    def __init__( self, period = 700, target = .3, stop_loss = .15, tsl_period = 10, useSD = False, save = True):
         self.period = period
         self.target = target
         self.stop_loss = stop_loss
         self.tsl_period = tsl_period
         self.useSD = useSD
+        self.save = save
         
         self.saved_data = self.loadFromFile()
     
     def saveToFile(self, data):
-        with open(self.file_path, 'w') as outfile:
-            json.dump(data, outfile)
+        if self.save:
+            with open(self.file_path, 'w') as outfile:
+                json.dump(data, outfile)
     
     def loadFromFile(self):
         try:
-            if os.path.exists(self.file_path):
+            if os.path.exists(self.file_path) and self.save:
                 with open(self.file_path) as f:
                     data = json.load(f)
                 return data
